# pygsmmodule

![](https://travis-ci.org/JFF-Bohdan/pygsmmodule.svg?branch=master)
[![Coverage Status](https://coveralls.io/repos/github/JFF-Bohdan/pygsmmodule/badge.svg?branch=master)](https://coveralls.io/github/JFF-Bohdan/pygsmmodule?branch=master)

Library for GSM modules (SIM-800/SIM-900) support.

